EXPORTS
	??0RDscStore@@QAE@XZ @ 1 NONAME ; RDscStore::RDscStore(void)
	??1CDscItem@@UAE@XZ @ 2 NONAME ; CDscItem::~CDscItem(void)
	?AddItemL@RDscStore@@QAEXAAVCDscItem@@@Z @ 3 NONAME ; void RDscStore::AddItemL(class CDscItem &)
	?AddItemL@RDscStore@@QAEXAAVCDscItem@@W4TDscPosition@@@Z @ 4 NONAME ; void RDscStore::AddItemL(class CDscItem &, enum TDscPosition)
	?Args@CDscItem@@QBE?AVTPtrC16@@XZ @ 5 NONAME ; class TPtrC16 CDscItem::Args(void) const
	?Close@RDscStore@@QAEXXZ @ 6 NONAME ; void RDscStore::Close(void)
	?CreateDscL@RDscStore@@QAEXABVTUid@@ABVTDesC16@@@Z @ 7 NONAME ; void RDscStore::CreateDscL(class TUid const &, class TDesC16 const &)
	?CreateDscL@RDscStore@@QAEXXZ @ 8 NONAME ; void RDscStore::CreateDscL(void)
	?DeleteDscL@RDscStore@@QAEXABVTUid@@@Z @ 9 NONAME ; void RDscStore::DeleteDscL(class TUid const &)
	?DeleteItemL@RDscStore@@QAEXABVCDscItem@@@Z @ 10 NONAME ; void RDscStore::DeleteItemL(class CDscItem const &)
	?DscExistsL@RDscStore@@QBEHABVTUid@@@Z @ 11 NONAME ; int RDscStore::DscExistsL(class TUid const &) const
	?DscExistsL@RDscStore@@QBEHXZ @ 12 NONAME ; int RDscStore::DscExistsL(void) const
	?DscId@CDscItem@@QBE?AVTUid@@XZ @ 13 NONAME ; class TUid CDscItem::DscId(void) const
	?EnumClose@RDscStore@@QAEXXZ @ 14 NONAME ; void RDscStore::EnumClose(void)
	?EnumOpenLC@RDscStore@@QAEXABVTUid@@@Z @ 15 NONAME ; void RDscStore::EnumOpenLC(class TUid const &)
	?EnumOpenLC@RDscStore@@QAEXXZ @ 16 NONAME ; void RDscStore::EnumOpenLC(void)
	?EnumReadNextL@RDscStore@@QAEPAVCDscItem@@XZ @ 17 NONAME ; class CDscItem * RDscStore::EnumReadNextL(void)
	?FileName@CDscItem@@QBE?AVTPtrC16@@XZ @ 18 NONAME ; class TPtrC16 CDscItem::FileName(void) const
	?GetDscDescriptionL@RDscStore@@QBEXABVTUid@@AAVTDes16@@@Z @ 19 NONAME ; void RDscStore::GetDscDescriptionL(class TUid const &, class TDes16 &) const
	?IsOpened@RDscStore@@QBEHXZ @ 20 NONAME ; int RDscStore::IsOpened(void) const
	?ItemExistsL@RDscStore@@QBEHABVCDscItem@@@Z @ 21 NONAME ; int RDscStore::ItemExistsL(class CDscItem const &) const
	?ItemId@CDscItem@@QBEHXZ @ 22 NONAME ; int CDscItem::ItemId(void) const
	?Monitored@CDscItem@@QBEHXZ @ 23 NONAME ; int CDscItem::Monitored(void) const
	?NewL@CDscItem@@SAPAV1@XZ @ 24 NONAME ; class CDscItem * CDscItem::NewL(void)
	?NoOfRetries@CDscItem@@QBEHXZ @ 25 NONAME ; int CDscItem::NoOfRetries(void) const
	?OpenL@RDscStore@@QAEXXZ @ 26 NONAME ; void RDscStore::OpenL(void)
	?ReadItemL@RDscStore@@QAEXAAVCDscItem@@@Z @ 27 NONAME ; void RDscStore::ReadItemL(class CDscItem &)
	?SetDscId@CDscItem@@QAEXABVTUid@@@Z @ 28 NONAME ; void CDscItem::SetDscId(class TUid const &)
	?SetFileParamsL@CDscItem@@QAEXABVTDesC16@@0@Z @ 29 NONAME ; void CDscItem::SetFileParamsL(class TDesC16 const &, class TDesC16 const &)
	?SetItemId@CDscItem@@QAEXH@Z @ 30 NONAME ; void CDscItem::SetItemId(int)
	?SetMonitored@CDscItem@@QAEXH@Z @ 31 NONAME ; void CDscItem::SetMonitored(int)
	?SetNoOfRetriesL@CDscItem@@QAEXH@Z @ 32 NONAME ; void CDscItem::SetNoOfRetriesL(int)
	?SetStartInBackground@CDscItem@@QAEXH@Z @ 33 NONAME ; void CDscItem::SetStartInBackground(int)
	?SetStartMethodL@CDscItem@@QAEXW4TStartMethod@@@Z @ 34 NONAME ; void CDscItem::SetStartMethodL(enum TStartMethod)
	?SetStartupType@CDscItem@@QAEXW4TStartupType@@@Z @ 35 NONAME ; void CDscItem::SetStartupType(enum TStartupType)
	?SetTimeoutL@CDscItem@@QAEXH@Z @ 36 NONAME ; void CDscItem::SetTimeoutL(int)
	?SetViewless@CDscItem@@QAEXH@Z @ 37 NONAME ; void CDscItem::SetViewless(int)
	?StartInBackground@CDscItem@@QBEHXZ @ 38 NONAME ; int CDscItem::StartInBackground(void) const
	?StartMethod@CDscItem@@QBE?AW4TStartMethod@@XZ @ 39 NONAME ; enum TStartMethod CDscItem::StartMethod(void) const
	?StartupProperties@CDscItem@@QBEABVCStartupProperties@@XZ @ 40 NONAME ; class CStartupProperties const & CDscItem::StartupProperties(void) const
	?StartupType@CDscItem@@QBE?AW4TStartupType@@XZ @ 41 NONAME ; enum TStartupType CDscItem::StartupType(void) const
	?Timeout@CDscItem@@QBEHXZ @ 42 NONAME ; int CDscItem::Timeout(void) const
	?UpdateItemL@RDscStore@@QAEXABVCDscItem@@@Z @ 43 NONAME ; void RDscStore::UpdateItemL(class CDscItem const &)
	?Viewless@CDscItem@@QBEHXZ @ 44 NONAME ; int CDscItem::Viewless(void) const
	?GetMaxStringLength@RDscStore@@QBEXAAH@Z @ 45 NONAME ; void RDscStore::MaxStringLength(int &) const
	?NewL@CDscItem@@SAPAV1@ABVTDesC16@@0@Z @ 46 NONAME ; class CDscItem * CDscItem::NewL(class TDesC16 const &, class TDesC16 const &)
	?NewLC@CDscItem@@SAPAV1@ABVTDesC16@@0@Z @ 47 NONAME ; class CDscItem * CDscItem::NewLC(class TDesC16 const &, class TDesC16 const &)
	?NewLC@CDscItem@@SAPAV1@XZ @ 48 NONAME ; class CDscItem * CDscItem::NewLC(void)
	?Reset@CDscItem@@QAEXXZ @ 49 NONAME ; void CDscItem::Reset(void)

